@@ -256,18 +256,10 @@ class AMLPipelineHelper:
         for output_key in output_names:
             output_instance = getattr(module_instance.outputs, output_key)
             if output_mode is None:
-                output_instance.configure(
-                    datastore=Datastore(
-                        current_workspace(),
-                        name=datastore_name,
-                    )  # datastore name for storing outputs
-                )
+                output_instance.configure(datastore=datastore_name)
             else:
                 output_instance.configure(
-                    datastore=Datastore(
-                        current_workspace(),
-                        name=datastore_name,
-                    ),  # datastore name for storing outputs
+                    datastore=datastore_name,
                     output_mode=output_mode,
                 )
             log.info(
@@ -1085,7 +1077,9 @@ class AMLPipelineHelper:
                         f"The pipeline tags {self.config.run.tags} is not a valid json-style string."
                     )
             elif isinstance(self.config.run.tags, DictConfig):
-                pipeline_tags.update(self.config.run.tags)
+                # NOTE: values for tags need to be str
+                for key, value in self.config.run.tags.items():
+                    pipeline_tags[key] = str(value)
             else:
                 log.warning(
                     f"The pipeline tags {self.config.run.tags} is not a valid DictConfig or json-style string."
@@ -1374,12 +1368,14 @@ class AMLPipelineHelper:
         pipeline = self.pipeline_instance(pipeline_function, self.config)
 
         log.info("Validating...")
-        pipeline.validate()
+        pipeline.validate(workspace=current_workspace())
 
         if self.config.run.export:
             log.info(f"Exporting to {self.config.run.export}...")
             with open(self.config.run.export, "w") as export_file:
-                export_file.write(pipeline._get_graph_json())
+                export_file.write(
+                    pipeline._get_graph_json(workspace=current_workspace())
+                )
 
         if self.config.run.submit:
             pipeline_tags = self._parse_pipeline_tags()
@@ -1390,6 +1386,7 @@ class AMLPipelineHelper:
             # pipeline_run is of the class "azure.ml.component.run", which
             # is different from "azureml.pipeline.core.PipelineRun"
             pipeline_run = pipeline.submit(
+                workspace=current_workspace(),
                 experiment_name=self.config.run.experiment_name,
                 description=self.config.run.experiment_description,
                 tags=pipeline_tags,
